@@ -1,28 +1,14 @@
 package Exporter::Handy;
 
+# ABSTRACT: An EXPERIMENTAL subclass of <Exporter::Extensible>, which helps create easy-to-extend modules that export symbols
+our $VERSION = '1.000003';
+
 use utf8;
 use strict;
 use warnings;
 
-# ABSTRACT: An EXPERIMENTAL subclass of <Exporter::Extensible>, which helps create easy-to-extend modules that export symbols
-our $VERSION = '1.000002';
-
 use Exporter::Extensible -exporter_setup => 1;
 
-# Generators for exported functions
-sub _generate_xtags : Export(=xtags) {
-  require Exporter::Handy::Util;
-  my ($exporter, $symbol, $opts) = @_;
-  my %opts = ( sig => ':',  %{; $opts // {} } );
-  sub {; Exporter::Handy::Util::xtags_( \%opts, @_ ) } # curried
-}
-
-sub _generate_expand_xtags : Export(=expand_xtags) {
-  require Exporter::Handy::Util;
-  my ($exporter, $symbol, $opts) = @_;
-  sub {; Exporter::Handy::Util::expand_xtags_(@_, $opts // { }) } # curried
-}
-
 
 # PRAGMATA
 # Remember: Pragmas effect the current compilation context.
@@ -44,9 +30,8 @@ sub sane : Export(-) {
   warnings->import;
 }
 
-
 # use Exporter::Handy qw(-sane -features), exporter_setup => 1;
-sub features {  # :Export(-?) syntax was not working before version 0.11 of Exporter::Extensible
+sub features {
   my ($exporter, $arg)= @_;
 
   # default features to turn on/off
@@ -95,6 +80,9 @@ sub features {  # :Export(-?) syntax was not working before version 0.11 of Expo
   feature->import(@on) if @on;
   feature->unimport(@off) if @off;
 }
+
+# Note that attribute syntax, i.e. :Export(-?), was not working before version 0.11 of <Exporter::Extensible>.
+# So we take the more verbose approach, as below:
 __PACKAGE__->exporter_register_option('features', \&features, '?');
 
 1;
@@ -114,7 +102,7 @@ Exporter::Handy - An EXPERIMENTAL subclass of <Exporter::Extensible>, which help
 
 =head1 VERSION
 
-version 1.000002
+version 1.000003
 
 =head1 SYNOPSIS
 
